@@ -1,7 +1,7 @@
+from typing import Optional
+
+from vkbottle_types.objects import BaseUploadServer, BaseBoolInt
 from .base_response import BaseResponse
-from vkbottle_types.objects import base
-from typing import Optional, Any, List, Union
-import typing
 
 
 class BoolResponse(BaseResponse):
@@ -15,11 +15,12 @@ class GetUploadServerResponse(BaseResponse):
 class OkResponse(BaseResponse):
     response: Optional["OkResponseModel"] = None
 
+BoolResponseModel = Optional[BaseBoolInt]
 
-BoolResponseModel = Optional["base.BoolInt"]
-
-
-GetUploadServerResponseModel = Optional["base.UploadServer"]
-
+GetUploadServerResponseModel = Optional[BaseUploadServer]
 
 OkResponseModel = int
+
+BoolResponse.update_forward_refs()
+GetUploadServerResponse.update_forward_refs()
+OkResponse.update_forward_refs()
