@@ -1,7 +1,7 @@
+from typing import Optional, List
+
+from vkbottle_types.objects import SearchHint
 from .base_response import BaseResponse
-from vkbottle_types.objects import search
-from typing import Optional, Any, List, Union
-import typing
 
 
 class GetHintsResponse(BaseResponse):
@@ -10,5 +10,7 @@ class GetHintsResponse(BaseResponse):
 
 class GetHintsResponseModel(BaseResponse):
     count: Optional[int] = None
-    items: Optional[List["search.Hint"]] = None
+    items: Optional[List["SearchHint"]] = None
     suggested_queries: Optional[List[str]] = None
+
+GetHintsResponse.update_forward_refs()
